@@ -30,7 +30,7 @@ import signal
 from socket import error as SocketError
 from client_exception import LdtpExecutionError, ERROR_CODE
 from log import logger
-from httplib import CannotSendRequest
+from httplib import CannotSendRequest, ResponseNotReady
 
 if 'LDTP_DEBUG' in os.environ:
     _ldtp_debug = os.environ['LDTP_DEBUG']
@@ -100,7 +100,7 @@ class Transport(xmlrpclib.Transport):
                     raise LdtpExecutionError(e.faultString.encode('utf-8'))
                 else:
                     raise e
-            except CannotSendRequest:
+            except (CannotSendRequest, ResponseNotReady):
                 # Use a clean connection and retry
                 if retry_count < 10:
                     # In python 2.7 / Ubuntu Natty 11.04
