@@ -1,3 +1,22 @@
+"""
+LDTP v2 client
+
+@author: Nagappan Alagappan <nagappan@gmail.com>
+@copyright: Copyright (c) 2009-11 Nagappan Alagappan
+@license: LGPL
+
+http://ldtp.freedesktop.org
+
+This file may be distributed and/or modified under the terms of the GNU General
+Public License version 2 as published by the Free Software Foundation. This file
+is distributed without any warranty; without even the implied warranty of 
+merchantability or fitness for a particular purpose.
+
+See 'COPYING' in the source distribution for more information.
+
+Headers in this file shall remain intact.
+"""
+
 ICONIFIED = "iconified"
 INVALID = "invalid"
 PRESSED = "pressed"
