@@ -1,10 +1,10 @@
-'''
+"""
 LDTP v2 Core Combo box.
 
 @author: Eitan Isaacson <eitan@ascender.com>
 @author: Nagappan Alagappan <nagappan@gmail.com>
 @copyright: Copyright (c) 2009 Eitan Isaacson
-@copyright: Copyright (c) 2009 Nagappan Alagappan
+@copyright: Copyright (c) 2009-11 Nagappan Alagappan
 @license: LGPL
 
 http://ldtp.freedesktop.org
@@ -14,10 +14,10 @@ Public License version 2 as published by the Free Software Foundation. This file
 is distributed without any warranty; without even the implied warranty of 
 merchantability or fitness for a particular purpose.
 
-See "COPYING" in the source distribution for more information.
+See 'COPYING' in the source distribution for more information.
 
 Headers in this file shall remain intact.
-'''
+"""
 
 import pyatspi 
 from utils import Utils
@@ -25,7 +25,7 @@ from server_exception import LdtpServerException
 
 class LayeredPane(Utils):
     def _lp_selectitem(self, obj, item_name):
-        '''
+        """
         Select layered pane item
 
         @param obj: Layered pane object
@@ -35,7 +35,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         index = 0
         for child in self._list_objects(obj):
             if child == obj:
@@ -64,7 +64,7 @@ class LayeredPane(Utils):
         raise LdtpServerException('Unable to select item')
 
     def _lp_selectindex(self, obj, item_index):
-        '''
+        """
         Select layered pane item based on index
 
         @param obj: Layered pane object
@@ -74,7 +74,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         selectioni = obj.querySelection()
         try:
             selectioni.selectChild(item_index)
@@ -83,7 +83,7 @@ class LayeredPane(Utils):
             raise LdtpServerException('Unable to select index')
 
     def unselectitem(self, window_name, object_name, item_name):
-        '''
+        """
         Select layered pane item
 
         @param window_name: Window name to type in, either full name,
@@ -96,7 +96,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -128,7 +128,7 @@ class LayeredPane(Utils):
         raise LdtpServerException('Unable to unselect item')
 
     def unselectindex(self, window_name, object_name, item_index):
-        '''
+        """
         Select layered pane item based on index
 
         @param window_name: Window name to type in, either full name,
@@ -142,7 +142,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -154,7 +154,7 @@ class LayeredPane(Utils):
             raise LdtpServerException('Unable to unselect index')
 
     def ischildselected(self, window_name, object_name, item_name):
-        '''
+        """
         Is layered pane item selected
 
         @param window_name: Window name to type in, either full name,
@@ -167,7 +167,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -190,7 +190,7 @@ class LayeredPane(Utils):
         return 0
 
     def ischildindexselected(self, window_name, object_name, item_index):
-        '''
+        """
         Is layered pane item selected in the given index
 
         @param window_name: Window name to type in, either full name,
@@ -204,7 +204,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -216,7 +216,7 @@ class LayeredPane(Utils):
         return 0
 
     def selecteditemcount(self, window_name, object_name):
-        '''
+        """
         Selected item count in layered pane
         
         @param window_name: Window name to type in, either full name,
@@ -228,7 +228,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -236,7 +236,7 @@ class LayeredPane(Utils):
         return selectioni.nSelectedChildren
 
     def selectall(self, window_name, object_name):
-        '''
+        """
         Select all item in layered pane
         
         @param window_name: Window name to type in, either full name,
@@ -248,7 +248,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -260,7 +260,7 @@ class LayeredPane(Utils):
             raise LdtpServerException('Unable to select all item')
 
     def unselectall(self, window_name, object_name):
-        '''
+        """
         Unselect all item in layered pane
         
         @param window_name: Window name to type in, either full name,
@@ -272,7 +272,7 @@ class LayeredPane(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -285,7 +285,7 @@ class LayeredPane(Utils):
 
 class ComboBox(Utils, LayeredPane):
     def selectitem(self, window_name, object_name, item_name):
-        '''
+        """
         Select combo box / layered pane item
         
         @param window_name: Window name to type in, either full name,
@@ -299,7 +299,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -341,7 +341,7 @@ class ComboBox(Utils, LayeredPane):
                         return 1
                 index += 1
         elif child_obj.getRole() == pyatspi.ROLE_MENU:
-            for child in self._list_objects (child_obj):
+            for child in self._list_objects(child_obj):
                 if child == child_obj:
                     # As the _list_objects gives the current object as well
                     # ignore it
@@ -349,6 +349,16 @@ class ComboBox(Utils, LayeredPane):
                 if self._glob_match(item_name, child.name):
                     self._click_object(child)
                     return 1
+                # Get LDTP format accessibile name
+                _ldtpize_accessible_name = self._ldtpize_accessible(child)
+                # Concat object type and object name
+                # ex: 'frmUnsavedDocument1-gedit' for Gedit application
+                # frm - Frame, Window title - 'Unsaved Document 1 - gedit'
+                _object_name = u'%s%s' % (_ldtpize_accessible_name[0],
+                                          _ldtpize_accessible_name[1])
+                if self._glob_match(item_name, _object_name):
+                    self._click_object(child)
+                    return 1
         raise LdtpServerException('Unable to select item')
 
     # Since selectitem and comboselect implementation are same,
@@ -356,7 +366,7 @@ class ComboBox(Utils, LayeredPane):
     comboselect = selectitem
 
     def selectindex(self, window_name, object_name, item_index):
-        '''
+        """
         Select combo box item / layered pane based on index
         
         @param window_name: Window name to type in, either full name,
@@ -370,7 +380,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -386,7 +396,7 @@ class ComboBox(Utils, LayeredPane):
             return 1
         elif child_obj.getRole() == pyatspi.ROLE_MENU:
             index = 0
-            for child in self._list_objects (child_obj):
+            for child in self._list_objects(child_obj):
                 if child == child_obj:
                     # As the _list_objects gives the current object as well
                     # ignore it
@@ -402,7 +412,7 @@ class ComboBox(Utils, LayeredPane):
     comboselectindex = selectindex
 
     def getallitem(self, window_name, object_name):
-        '''
+        """
         Select combo box item
         
         @param window_name: Window name to type in, either full name,
@@ -414,7 +424,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: list of string on success.
         @rtype: list
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -423,7 +433,7 @@ class ComboBox(Utils, LayeredPane):
             raise LdtpServerException('Unable to get combo box children')
         item_list = []
         if child_obj.getRole() == pyatspi.ROLE_LIST:
-            for child in self._list_objects (child_obj):
+            for child in self._list_objects(child_obj):
                 if child == child_obj:
                     # As the _list_objects gives the current object as well
                     # ignore it
@@ -437,7 +447,7 @@ class ComboBox(Utils, LayeredPane):
                 item_list.append(text)
             return item_list
         elif child_obj.getRole() == pyatspi.ROLE_MENU:
-            for child in self._list_objects (child_obj):
+            for child in self._list_objects(child_obj):
                 if child == child_obj:
                     # As the _list_objects gives the current object as well
                     # ignore it
@@ -448,7 +458,7 @@ class ComboBox(Utils, LayeredPane):
         raise LdtpServerException('Unable to select item')
 
     def showlist(self, window_name, object_name):
-        '''
+        """
         Show combo box list / menu
         
         @param window_name: Window name to type in, either full name,
@@ -460,7 +470,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -474,7 +484,7 @@ class ComboBox(Utils, LayeredPane):
         return 1
 
     def hidelist(self, window_name, object_name):
-        '''
+        """
         Hide combo box list / menu
         
         @param window_name: Window name to type in, either full name,
@@ -486,7 +496,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
         self._grab_focus(obj)
 
@@ -500,7 +510,7 @@ class ComboBox(Utils, LayeredPane):
         return 1
 
     def verifydropdown(self, window_name, object_name):
-        '''
+        """
         Verify drop down list / menu poped up
         
         @param window_name: Window name to type in, either full name,
@@ -512,7 +522,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
             self._grab_focus(obj)
@@ -532,7 +542,7 @@ class ComboBox(Utils, LayeredPane):
         return 0
 
     def verifyshowlist(self, window_name, object_name):
-        '''
+        """
         Verify drop down list / menu poped up
         
         @param window_name: Window name to type in, either full name,
@@ -544,11 +554,11 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         return self.verifydropdown(window_name, object_name)
 
     def verifyhidelist(self, window_name, object_name):
-        '''
+        """
         Verify list / menu is hidden in combo box
         
         @param window_name: Window name to type in, either full name,
@@ -560,7 +570,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
             self._grab_focus(obj)
@@ -581,7 +591,7 @@ class ComboBox(Utils, LayeredPane):
         return 0
 
     def verifyselect(self, window_name, object_name, item_name):
-        '''
+        """
         Verify the item selected in combo box
         
         @param window_name: Window name to type in, either full name,
@@ -595,7 +605,7 @@ class ComboBox(Utils, LayeredPane):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
             self._grab_focus(obj)
@@ -604,7 +614,7 @@ class ComboBox(Utils, LayeredPane):
             if not child_obj:
                 return 0
             if child_obj.getRole() == pyatspi.ROLE_LIST:
-                for child in self._list_objects (child_obj):
+                for child in self._list_objects(child_obj):
                     if child == child_obj:
                         # As the _list_objects gives the current object as well
                         # ignore it
@@ -618,13 +628,22 @@ class ComboBox(Utils, LayeredPane):
                     if self._glob_match(item_name, text):
                         return 1
             elif child_obj.getRole() == pyatspi.ROLE_MENU:
-                for child in self._list_objects (child_obj):
+                for child in self._list_objects(child_obj):
                     if child == child_obj:
                         # As the _list_objects gives the current object as well
                         # ignore it
                         continue
                     if self._glob_match(item_name, child.name):
                         return 1
+                    # Get LDTP format accessibile name
+                    _ldtpize_accessible_name = self._ldtpize_accessible(child)
+                    # Concat object type and object name
+                    # ex: 'frmUnsavedDocument1-gedit' for Gedit application
+                    # frm - Frame, Window title - 'Unsaved Document 1 - gedit'
+                    _object_name = u'%s%s' % (_ldtpize_accessible_name[0],
+                                              _ldtpize_accessible_name[1])
+                    if self._glob_match(item_name, _object_name):
+                        return 1
         except:
             pass
         return 0
