@@ -22,6 +22,15 @@ Headers in this file shall remain intact.
 from pyatspi import findDescendant, Registry
 import locale
 import subprocess
+try:
+  # If we have gtk3+ gobject introspection, use that
+  from gi.repository import Wnck as wnck, Gtk as gtk, GObject as gobject
+  gtk3 = True
+except:
+  # No gobject introspection, use gtk2 libwnck
+  import gtk
+  import wnck
+  gtk3 = False
 from utils import Utils, ProcessStats
 from constants import abbreviated_roles
 from keypress_actions import KeyboardOp
@@ -33,9 +42,7 @@ from server_exception import LdtpServerException
 import os
 import re
 import sys
-import gtk
 import time
-import wnck
 import pyatspi
 import traceback
 from fnmatch import translate as glob_trans
@@ -168,7 +175,25 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
     def isalive(self):
         return True
 
-    def launchapp(self, cmd, args = [], delay = 0, env = 1):
+    def handletablecell(self):
+        self._handle_table_cell = True
+
+    def unhandletablecell(self):
+        self._handle_table_cell = False
+
+    def delaycmdexec(self, delay = None):
+        """
+        Delay command execution
+
+        @param delay: Delay after the application is launched
+        @type delay: float
+
+        @return: 1 on success
+        @rtype: integer
+        """
+        self._delaycmdexec = delay
+
+    def launchapp(self, cmd, args = [], delay = 0, env = 1, lang = "C"):
         """
         Launch application.
 
@@ -180,6 +205,8 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
         @type delay: int
         @param env: GNOME accessibility environment to be set or not
         @type env: int
+        @param lang: Application language to be used
+        @type lang: string
 
         @return: PID of new process
         @rtype: integer
@@ -191,6 +218,8 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
         if env:
             os.environ['GTK_MODULES'] = 'gail:atk-bridge'
             os.environ['GNOME_ACCESSIBILITY'] = '1'
+        if lang:
+            os.environ['LANG'] = lang
         try:
             process = subprocess.Popen([cmd]+args, close_fds = True)
             # Let us wait so that the application launches
@@ -834,6 +863,43 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
         """
         return self.verifycheck(window_name, object_name)
 
+    def verifytoggled(self, window_name, object_name):
+        """
+        Verify toggle item toggled.
+        
+        @param window_name: Window name to look for, either full name,
+        LDTP's name convention, or a Unix glob.
+        @type window_name: string
+        @param object_name: Object name to look for, either full name,
+        LDTP's name convention, or a Unix glob. 
+        @type object_name: string
+
+        @return: 1 on success 0 on failure.
+        @rtype: integer
+        """
+        return self.verifycheck(window_name, object_name)
+
+    def verifypushbutton(self, window_name, object_name):
+        """
+        Verify whether the object is push button or not.
+        
+        @param window_name: Window name to look for, either full name,
+        LDTP's name convention, or a Unix glob.
+        @type window_name: string
+        @param object_name: Object name to look for, either full name,
+        LDTP's name convention, or a Unix glob. 
+        @type object_name: string
+
+        @return: 1 on success 0 on failure.
+        @rtype: integer
+        """
+        try:
+            obj = self._get_object(window_name, object_name)
+
+            return int(obj.getRole() == pyatspi.ROLE_PUSH_BUTTON)
+        except:
+            return 0
+
     def verifycheck(self, window_name, object_name):
         """
         Verify check item.
@@ -855,6 +921,27 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
         except:
             return 0
 
+    def getpanelchildcount(self, window_name, object_name):
+        """
+        Get panel child count.
+        
+        @param window_name: Window name to look for, either full name,
+        LDTP's name convention, or a Unix glob.
+        @type window_name: string
+        @param object_name: Object name to look for, either full name,
+        LDTP's name convention, or a Unix glob. 
+        @type object_name: string
+
+        @return: 1 on success, -1 on failure.
+        @rtype: integer
+        """
+        try:
+            obj = self._get_object(window_name, object_name)
+
+            return obj.childCount
+        except:
+            return -1
+
     def verifyuncheck(self, window_name, object_name):
         """
         Verify uncheck item.
@@ -1170,6 +1257,7 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
         # Following lines from Accerciser, _getComponentAtCoords method
         # quick_select.py file
         container = parent
+        inner_container = parent
         while True:
             container_role = container.getRole()
             if container_role == pyatspi.ROLE_PAGE_TAB_LIST:
@@ -1210,14 +1298,22 @@ class Ldtpd(Utils, ComboBox, Table, Menu, PageTabList,
         # Following lines from Accerciser, _inspectUnderMouse method
         # quick_select.py file
         # Inspect accessible under mouse
-        display = gtk.gdk.Display(gtk.gdk.get_display())
-        screen, x, y, flags =  display.get_pointer()
-        del screen # A workaround http://bugzilla.gnome.org/show_bug.cgi?id=593732
-        wnck_screen = wnck.screen_get_default()
+        if gtk3:
+           display = gdk.get_default_root_window()
+           screen, x, y, flags = display.get_pointer()
+        else:
+           display = gtk.gdk.Display(gtk.gdk.get_display())
+           screen, x, y, flags = display.get_pointer()
+           del screen # A workaround http://bugzilla.gnome.org/show_bug.cgi?id=593732
         # Bug in wnck, if the following 2 lines are not called
         # wnck returns empty list
         while gtk.events_pending():
             gtk.main_iteration()
+        if gtk3:
+          wnck_screen = wnck.Screen.get_default()
+        else:
+          wnck_screen = wnck.screen_get_default()
+        wnck_screen.force_update()
 
         window_order = [(w.get_name(), w) \
                         for w in wnck_screen.get_windows_stacked()]
