@@ -172,10 +172,12 @@ class Utils:
         self._states = {}
         self._appmap = {}
         self._callback = {}
+        self._states_old = {}
         self._logger = logger
         self._state_names = {}
         self._window_uptime = {}
         self._callback_event = []
+        self._delaycmdexec = None
         self._get_all_state_names()
         self._handle_table_cell = False
         self._custom_logger = _custom_logger
@@ -214,10 +216,12 @@ class Utils:
         NOTE: Just called once, internally
         """
         for state in pyatspi.STATE_VALUE_TO_NAME.keys():
-            self._states[state.__repr__()] = state
+            self._states_old[state.__repr__()] = state
+            # b.g.o Bug#654683
+            self._states[str(state)] = state
             # Ignore STATE_ string for LDTPv1 compatibility
             self._state_names[state] = \
-                state.__repr__().lower().partition("state_")[2]
+                str(state).lower().partition("state_")[2]
         return self._states
 
     def _obj_changed(self, event):
@@ -331,8 +335,11 @@ class Utils:
         @rtype: tuple
         """
         label_by = label_acc = None
-        # Get accessible relation set
-        rel_set = acc.getRelationSet()
+        try:
+            # Get accessible relation set
+            rel_set = acc.getRelationSet()
+        except LookupError:
+            rel_set = None
         if rel_set:
             for i, rel in enumerate(rel_set):
                 relationType = rel.getRelationType()
@@ -373,8 +380,12 @@ class Utils:
         # Return the role type (if, not in the know list of roles,
         # return ukn - unknown), strip the above characters from name
         # also return labely_by string
+        try:
+            label = re.sub(strip, '', (label_acc or acc).name)
+        except LookupError:
+            label = ''
         return abbreviated_roles.get(role, 'ukn'), \
-            re.sub(strip, '', (label_acc or acc).name), \
+            label, \
             label_by
 
     def _glob_match(self, pattern, string):
@@ -553,7 +564,10 @@ class Utils:
             ldtpized_name = u'%s%d' % (ldtpized_name_base,
                                       self.ldtpized_obj_index[abbrev_role])
         else:
-            ldtpized_name_base = u'%s%s' % (abbrev_role, abbrev_name)
+            try:
+               ldtpized_name_base = u'%s%s' % (abbrev_role, abbrev_name)
+            except UnicodeDecodeError:
+               ldtpized_name_base = u'%s%s' % (abbrev_role, abbrev_name.decode('utf-8'))
             ldtpized_name = ldtpized_name_base
         i = 0
         while ldtpized_name in self.ldtpized_list:
@@ -592,7 +606,8 @@ class Utils:
                 index += 1
                 if not child:
                     continue
-                if child.getRole() == pyatspi.ROLE_TABLE_CELL:
+                if not self._handle_table_cell and \
+                       child.getRole() == pyatspi.ROLE_TABLE_CELL:
                     break
                 self._populate_appmap(child, parent, index)
 
@@ -625,20 +640,32 @@ class Utils:
             _parent = abbrev_name
         else:
             _parent = ''
-        self._populate_appmap(gui, _parent, gui.getIndexInParent())
+        try:
+            self._populate_appmap(gui, _parent, gui.getIndexInParent())
+        except LookupError:
+            raise LdtpServerException("Unable to find window/object")
         self._appmap[window_name] = self.ldtpized_list
         return self.ldtpized_list
 
-    def _get_menu_hierarchy(self, window_name, object_name):
+    def _get_menu_hierarchy(self, window_name, object_name,
+                            strict_hierarchy = False):
         _menu_hierarchy = re.split(';', object_name)
+        if strict_hierarchy and len(_menu_hierarchy) <= 1:
+            # If strict_hierarchy is set and _menu_hierarchy doesn't have
+            # hierarchy menu's with ; seperated, then raise exception
+            # Fixes bug #590111 - It would be nice if doesmenuexist could
+            # search for strict hierarchies
+            raise LdtpServerException("Invalid menu hierarchy input")
         if not re.search('^mnu', _menu_hierarchy[0], re.M | re.U):
-            _menu_hierarchy[0] = 'mnu%s' % _menu_hierarchy[0]
+            # Add mnu to the first object, if it doesn't exist
+            _menu_hierarchy[0] = u'mnu%s' % _menu_hierarchy[0]
         obj = self._get_object(window_name, _menu_hierarchy[0])
         for _menu in _menu_hierarchy[1:]:
             _flag = False
             for _child in self._list_objects(obj):
                 if obj == _child:
-                    # if the given object and child object matches
+                    # if the given object and child object matches, as
+                    # the _list_objects return object as one of the _child
                     continue
                 if self._match_name_to_acc(_menu, _child):
                     _flag = True
