@@ -1,10 +1,10 @@
-'''
+"""
 LDTP v2 Core Value.
 
 @author: Eitan Isaacson <eitan@ascender.com>
 @author: Nagappan Alagappan <nagappan@gmail.com>
 @copyright: Copyright (c) 2009 Eitan Isaacson
-@copyright: Copyright (c) 2009 Nagappan Alagappan
+@copyright: Copyright (c) 2009-11 Nagappan Alagappan
 @license: LGPL
 
 http://ldtp.freedesktop.org
@@ -14,10 +14,11 @@ Public License version 2 as published by the Free Software Foundation. This file
 is distributed without any warranty; without even the implied warranty of 
 merchantability or fitness for a particular purpose.
 
-See "COPYING" in the source distribution for more information.
+See 'COPYING' in the source distribution for more information.
 
 Headers in this file shall remain intact.
-'''
+"""
+
 import time
 import pyatspi 
 from utils import Utils
@@ -25,7 +26,7 @@ from server_exception import LdtpServerException
 
 class Value(Utils):
     def setvalue(self, window_name, object_name, data):
-        '''
+        """
         Type string sequence.
         
         @param window_name: Window name to type in, either full name,
@@ -39,7 +40,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -51,7 +52,7 @@ class Value(Utils):
         return 1
 
     def getvalue(self, window_name, object_name):
-        '''
+        """
         Get object value
         
         @param window_name: Window name to type in, either full name,
@@ -62,8 +63,8 @@ class Value(Utils):
         @type object_name: string
 
         @return: value on success.
-        @rtype: float
-        '''
+        @rtype: double
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -74,7 +75,7 @@ class Value(Utils):
         return valuei.currentValue
 
     def getslidervalue(self, window_name, object_name):
-        '''
+        """
         Get slider value
         
         @param window_name: Window name to type in, either full name,
@@ -85,12 +86,12 @@ class Value(Utils):
         @type object_name: string
 
         @return: value on success.
-        @rtype: float
-        '''
+        @rtype: double
+        """
         return self.getvalue(window_name, object_name)
 
     def verifysetvalue(self, window_name, object_name, data):
-        '''
+        """
         Get object value
         
         @param window_name: Window name to type in, either full name,
@@ -104,7 +105,7 @@ class Value(Utils):
 
         @return: 1 on success 0 on failure.
         @rtype: 1
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
             valuei = obj.queryValue()
@@ -116,7 +117,7 @@ class Value(Utils):
         return 0
 
     def getminvalue(self, window_name, object_name):
-        '''
+        """
         Get object min value
         
         @param window_name: Window name to type in, either full name,
@@ -127,8 +128,8 @@ class Value(Utils):
         @type object_name: string
 
         @return: float value on success.
-        @rtype: float
-        '''
+        @rtype: double
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -138,8 +139,11 @@ class Value(Utils):
 
         return valuei.minimumValue
 
+    # Name compatibility with setmin
+    getmin = getminvalue
+
     def getminincrement(self, window_name, object_name):
-        '''
+        """
         Get object min increment value
         
         @param window_name: Window name to type in, either full name,
@@ -150,8 +154,8 @@ class Value(Utils):
         @type object_name: string
 
         @return: float value on success.
-        @rtype: float
-        '''
+        @rtype: double
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -162,7 +166,7 @@ class Value(Utils):
         return valuei.minimumIncrement
 
     def getmaxvalue(self, window_name, object_name):
-        '''
+        """
         Get object max value
         
         @param window_name: Window name to type in, either full name,
@@ -173,8 +177,8 @@ class Value(Utils):
         @type object_name: string
 
         @return: float value on success.
-        @rtype: float
-        '''
+        @rtype: double
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -184,8 +188,11 @@ class Value(Utils):
 
         return valuei.maximumValue
 
+    # Name compatibility with setmax
+    getmax = getmaxvalue
+
     def verifyslidervertical(self, window_name, object_name):
-        '''
+        """
         Verify slider is vertical
         
         @param window_name: Window name to type in, either full name,
@@ -197,7 +204,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
 
@@ -208,7 +215,7 @@ class Value(Utils):
         return 0
 
     def verifysliderhorizontal(self, window_name, object_name):
-        '''
+        """
         Verify slider is horizontal
         
         @param window_name: Window name to type in, either full name,
@@ -220,7 +227,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
 
@@ -231,7 +238,7 @@ class Value(Utils):
         return 0
 
     def verifyscrollbarvertical(self, window_name, object_name):
-        '''
+        """
         Verify scrollbar is vertical
         
         @param window_name: Window name to type in, either full name,
@@ -243,7 +250,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
 
@@ -254,7 +261,7 @@ class Value(Utils):
         return 0
 
     def verifyscrollbarhorizontal(self, window_name, object_name):
-        '''
+        """
         Verify scrollbar is horizontal
         
         @param window_name: Window name to type in, either full name,
@@ -266,7 +273,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         try:
             obj = self._get_object(window_name, object_name)
 
@@ -277,7 +284,7 @@ class Value(Utils):
         return 0
 
     def scrollup(self, window_name, object_name):
-        '''
+        """
         Scroll up
         
         @param window_name: Window name to type in, either full name,
@@ -289,13 +296,13 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarvertical(window_name, object_name):
             raise LdtpServerException('Object not vertical scrollbar')
         return self.setmin(window_name, object_name)
 
     def scrolldown(self, window_name, object_name):
-        '''
+        """
         Scroll down
         
         @param window_name: Window name to type in, either full name,
@@ -307,13 +314,13 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarvertical(window_name, object_name):
             raise LdtpServerException('Object not vertical scrollbar')
         return self.setmax(window_name, object_name)
 
     def scrollleft(self, window_name, object_name):
-        '''
+        """
         Scroll left
         
         @param window_name: Window name to type in, either full name,
@@ -325,13 +332,13 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarhorizontal(window_name, object_name):
             raise LdtpServerException('Object not horizontal scrollbar')
         return self.setmin(window_name, object_name)
 
     def scrollright(self, window_name, object_name):
-        '''
+        """
         Scroll right
         
         @param window_name: Window name to type in, either full name,
@@ -343,13 +350,13 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarhorizontal(window_name, object_name):
             raise LdtpServerException('Object not horizontal scrollbar')
         return self.setmax(window_name, object_name)
 
     def setmax(self, window_name, object_name):
-        '''
+        """
         Set max value
         
         @param window_name: Window name to type in, either full name,
@@ -361,7 +368,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -373,7 +380,7 @@ class Value(Utils):
         return 1
 
     def setmin(self, window_name, object_name):
-        '''
+        """
         Set min value
         
         @param window_name: Window name to type in, either full name,
@@ -385,7 +392,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -397,7 +404,7 @@ class Value(Utils):
         return 1
 
     def increase(self, window_name, object_name, iterations):
-        '''
+        """
         Increase slider with number of iterations
         
         @param window_name: Window name to type in, either full name,
@@ -411,7 +418,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -434,7 +441,7 @@ class Value(Utils):
             raise LdtpServerException('Unable to increase slider value')
 
     def decrease(self, window_name, object_name, iterations):
-        '''
+        """
         Decrease slider with number of iterations
         
         @param window_name: Window name to type in, either full name,
@@ -448,7 +455,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         obj = self._get_object(window_name, object_name)
 
         try:
@@ -471,7 +478,7 @@ class Value(Utils):
             raise LdtpServerException('Unable to decrease slider value')
 
     def onedown(self, window_name, object_name, iterations):
-        '''
+        """
         Press scrollbar down with number of iterations
         
         @param window_name: Window name to type in, either full name,
@@ -485,7 +492,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarvertical(window_name, object_name):
             raise LdtpServerException('Object not vertical scrollbar')
 
@@ -512,7 +519,7 @@ class Value(Utils):
             raise LdtpServerException('Unable to increase scrollbar')
 
     def oneup(self, window_name, object_name, iterations):
-        '''
+        """
         Press scrollbar up with number of iterations
         
         @param window_name: Window name to type in, either full name,
@@ -526,7 +533,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarvertical(window_name, object_name):
             raise LdtpServerException('Object not vertical scrollbar')
 
@@ -553,7 +560,7 @@ class Value(Utils):
             raise LdtpServerException('Unable to decrease scrollbar')
 
     def oneright(self, window_name, object_name, iterations):
-        '''
+        """
         Press scrollbar right with number of iterations
         
         @param window_name: Window name to type in, either full name,
@@ -567,7 +574,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarhorizontal(window_name, object_name):
             raise LdtpServerException('Object not horizontal scrollbar')
 
@@ -594,7 +601,7 @@ class Value(Utils):
             raise LdtpServerException('Unable to increase scrollbar')
 
     def oneleft(self, window_name, object_name, iterations):
-        '''
+        """
         Press scrollbar left with number of iterations
         
         @param window_name: Window name to type in, either full name,
@@ -608,7 +615,7 @@ class Value(Utils):
 
         @return: 1 on success.
         @rtype: integer
-        '''
+        """
         if not self.verifyscrollbarhorizontal(window_name, object_name):
             raise LdtpServerException('Object not horizontal scrollbar')
 
